package com.boman.web.core.controller;
import com.boman.common.core.utils.poi.ExcelUtil;

import com.boman.common.core.web.controller.BaseController;
import com.boman.common.log.annotation.Log;
import com.boman.common.log.enums.BusinessType;
import com.boman.common.security.annotation.PreAuthorize;
import com.boman.domain.Czrk;
import com.boman.domain.TableDataInfo;
import com.boman.domain.dto.AjaxResult;
import com.boman.web.core.domain.AccountingData;
import com.boman.web.core.domain.vo.AccountingDataVo;
import com.boman.web.core.service.TaskService;
import com.boman.web.core.service.accounting.IAccountingDataService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * 潜山核酸数据Controller
 *
 * @author ruoyi
 * @date 2022-01-14
 */
@RestController
@RequestMapping("/core/account")
@Slf4j
public class AccountingDataController extends BaseController {

    @Resource
    private IAccountingDataService accountingDataService;

    @Resource
    private TaskService taskService;

    /***
     *  潜山核酸数据列表页(根据户籍地)
     * @return
     */
    @GetMapping("/nucleicAcid/hj")
    public TableDataInfo nucleicAcidHj( AccountingDataVo accountingData) {
        List<AccountingDataVo> list = accountingDataService.nucleicAcidHJList(accountingData);
        return getDataTable(list);
    }

    /***
     *  潜山核酸数据列表页(根据居住地址)
     * @return
     */
    @GetMapping("/nucleicAcid/jzdz")
    public TableDataInfo nucleicAcidJzdz( AccountingDataVo accountingData) {
        List<AccountingDataVo> list = accountingDataService.nucleicAcidJzdzList(accountingData);
        return getDataTable(list);
    }

    /***
     * 潜山来宜人员数据
     * @param rc
     * @param djsjqs
     * @param djsjjs
     * @param name
     * @param sfzhm
     * @return
     */
    @GetMapping("/toQianshan")
    public AjaxResult toQianshan(String rc, String djsjqs, String djsjjs, String name, String sfzhm) {
        return accountingDataService.toQianshan(rc,djsjqs,djsjjs,name,sfzhm);
    }

    /**
     *  核酸数据导出
     * @param response
     * @param accountingData
     * @throws IOException
     */
    @Log(title = "核酸数据", businessType = BusinessType.EXPORT)
    @PreAuthorize(hasPermi = "system:accountingData:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, @RequestBody AccountingData accountingData) throws IOException
    {
        List<AccountingData> accountingDataList = accountingDataService.getExport(accountingData);
        ExcelUtil<AccountingData> util = new ExcelUtil<>(AccountingData.class);
        util.exportExcel(response, accountingDataList, "核酸数据");
    }

    @GetMapping("/nucleicAcid/zz")
    public void nucleicAci() {
        taskService.insertAccountingData();
    }
}
